@@ -360,7 +360,7 @@ class AtomInfo(ToXMLHelper):
         self.atomtypes=AtomtypesArray()
         if init:
             if type(init) is IntType:
-                self.allocate(i)
+                self.allocate(init)
             elif type(init) in StringTypes:
                 dom=parseXML(init)
                 self.readFromNode(dom.getElementsByTagName("atominfo")[0])
@@ -467,6 +467,12 @@ class AtomInfo(ToXMLHelper):
             a.append(r.getRecord())
         return a
 
+    def downscale(self,factor):
+        """Reduce the number all atom types by given factor.
+    This can be used e.g. when reducing a supercell atominfo to a primitive cell."""
+        for i in range(len(self)):
+            self[i].atomspertype=self[i].atomspertype/factor
+
     def writexml(self,f,indent=0,extended=0):
         """Write in xml representation to a file *f*, indented by *indent* (integer).
     When *extended* is true, write also redundant informations.
