@@ -39,6 +39,7 @@ Following calculation properties are available:
   ||KEYWORDS                || string                                  || keywords (currently only supported in a database ||
   ||GENERATORINFO           || p4vasp.Dictionary.Incar                 || generator info (date, time, VASP version)        ||
   ||INCAR                   || p4vasp.Dictionary.Incar                 || INCAR dictionary                                 ||
+  ||DYNA                    || p4vasp.Dyna.Dyna                        || DYNA structure with k-points segments            ||
   ||PARAMETERS              || p4vasp.Dictionary.Incar                 || all VASP parameters (INCAR+defaults)             ||
   ||NAME                    || string                                  || name, typically from INCAR SYSTEM tag            ||
   ||ATOMINFO                || p4vasp.Structure.AtomInfo               ||  AtomInfo structure                              ||
@@ -47,6 +48,7 @@ Following calculation properties are available:
   ||PARTIAL_DOS_L           || p4vasp.Array.Array (with LateLists)     || partial density of states (LateList version)     ||
   ||INITIAL_STRUCTURE       || p4vasp.Structure.Structure              || initial structure                                ||
   ||FINAL_STRUCTURE         || p4vasp.Structure.Structure              || final structure                                  ||
+  ||PRIMITIVE_STRUCTURE     || p4vasp.Structure.Structure              || primitive cell structure                         ||
   ||STRUCTURE_SEQUENCE      || list of p4vasp.Structure.Structure      || structures in relaxation run                     ||
   ||STRUCTURE_SEQUENCE_L    || LateList of p4vasp.Structure.Structure  || structures in relaxation run (LateList version)  ||
   ||CSTRUCTURE_SEQUENCE_L   || LateList of p4vasp.cStructure.Structure || c-structures in relaxation run (LateList version)||
@@ -57,6 +59,7 @@ Following calculation properties are available:
   ||FREE_ENERGY             || float                                   || free energy (last of the FREE_ENERGY_SEQUENCE)   ||
   ||FORCES_SEQUENCE         || list of lists                           || sequence of forces                               ||
   ||FORCES_SEQUENCE_L       || LateList of lists                       || sequence of forces (LateList version)            ||
+  ||FORCE_CONSTANTS         || p4vasp.Array.Array                      || force constants                                  ||
   ||VELOCITY_SEQUENCE       || list of lists                           || sequence of velocities                           ||
   ||VELOCITY_SEQUENCE_L     || LateList of lists                       || sequence of velocities (LateList version)        ||
   ||EIGENVALUES             || p4vasp.Array.Array                      || eigenvalues                                      ||
@@ -296,11 +299,12 @@ class SystemPM(PropertyManager):
         self.add("PARCHG_Y",read=lambda x:ChgcarStatisticsLateList(x.manager["PARCHG"].get(),1))
         self.add("PARCHG_Z",read=lambda x:ChgcarStatisticsLateList(x.manager["PARCHG"].get(),2))
         self.add("KEYWORDS",read=lambda x:"")
-        self.add("DATE",    read=self.getDate)
-        self.add("PROGRAM", read=self.getProgram)
-        self.add("VERSION",    read=self.getVersion)
+        self.add("DYNA",          read=self.getDyna)
+        self.add("DATE",          read=self.getDate)
+        self.add("PROGRAM",       read=self.getProgram)
+        self.add("VERSION",       read=self.getVersion)
         self.add("SUBVERSION",    read=self.getSubversion)
-        self.add("PLATFORM",    read=self.getPlatform)
+        self.add("PLATFORM",      read=self.getPlatform)
 
 
     def getDate(self,x):
@@ -314,9 +318,14 @@ class SystemPM(PropertyManager):
     def getPlatform(self,x):
         return None
 
-
-
-
+    def getDyna(self,x):
+        import p4vasp.Dyna
+        p=os.path.join(x.manager.PATH,"DYNA")
+        msg().message("get DYNA file %s"%p)
+        if os.path.isfile(p):
+            return p4vasp.Dyna.Dyna(p)
+        else:
+            return None
     def getChargeFile(self,x,f):
         p=os.path.join(x.manager.PATH,f)
         msg().message("get Charge file %s"%p)
@@ -441,6 +450,7 @@ class XMLSystemPM(SystemPM):
         self.add("PARTIAL_DOS_L",           read     =self.getPartialDOS_L)
         self.add("INITIAL_STRUCTURE",       read     =self.getInitialStructure)
         self.add("FINAL_STRUCTURE",         read     =self.getFinalStructure)
+        self.add("PRIMITIVE_STRUCTURE",     read     =self.getPrimitiveStructure)
         self.add("E_FERMI",                 read     =self.getEFermi)
         self.add("EIGENVALUES",             read     =self.getEigenvalues)
         self.add("EIGENVALUES_L",           read     =self.getEigenvalues_L)
@@ -461,6 +471,7 @@ class XMLSystemPM(SystemPM):
         self.add("FORCES_SEQUENCE",               read     =self.getForcesSequence,
                                                   generator=self.getForcesSequenceGen)
         self.add("FORCES_SEQUENCE_L",             read     =self.getForcesSequence_L)
+        self.add("FORCE_CONSTANTS",               read     =self.getForceConstants)
         self.add("VELOCITIES_SEQUENCE",           read     =self.getVelocitiesSequence,
                                                   generator=self.getVelocitiesSequenceGen)
         self.add("VELOCITIES_SEQUENCE_L",         read     =self.getVelocitiesSequence_L)
@@ -1002,40 +1013,52 @@ class XMLSystemPM(SystemPM):
         msg().error("Error - no projected eigenvalues available")
 
 
-    def getInitialStructure(self,x):
-        msg().status("Parsing initial structure")
+    def fetchStructure(self,x,token,name):
+        msg().status("Parsing %s"%name)
         try:
             dom=x.manager.DOM
             atominfo=x.manager.ATOMINFO
             for e in dom.getElementsByTagName("structure"):
-                if e.getAttribute("name")=="initialpos":
+                if e.getAttribute("name")==token:
                     s=Structure()
                     s.readFromNode(e,atominfo)
                     msg().status("OK")
                     return s
         except:
-            msg().error("Error - no initial structure available")
+            msg().error("Error - no %s available"%name)
             msg().exception()
-        msg().error("Error - no initial structure available, empty structure created.")
+        msg().error("Error - no %s available, empty structure created."%name)
         return Structure() # Empty structure if no structure is found.
 
+    def getInitialStructure(self,x):
+        return self.fetchStructure(x,"initialpos","initial structure")
 
     def getFinalStructure(self,x):
-        msg().status("Parsing final structure")
+        return self.fetchStructure(x,"finalpos","final structure")
+
+    def getPrimitiveStructure(self,x):
+        s=self.fetchStructure(x,"primitive_cell","primitive cell")
+        # Temporary hack which allows to display structure even without correct atominfo
+        s.info = AtomInfo(s.info)
+        s.info.downscale(len(self.INITIAL_STRUCTURE)/len(s))
+        return s
+
+    def getForceConstants(self,x):
+        msg().status("Parsing force constants")
         try:
             dom=x.manager.DOM
-            atominfo=x.manager.ATOMINFO
-            for e in dom.getElementsByTagName("structure"):
-                if e.getAttribute("name")=="finalpos":
-                    s=Structure()
-                    s.readFromNode(e,atominfo)
+            for e in dom.getElementsByTagName("array"):
+                if e.getAttribute("name") == "force_constants":
+                    a=Array(e,fastflag=1)
                     msg().status("OK")
-                    return s
+                    return a
         except:
-            msg().error("Error - no final structure available")
+            msg().error("Force constants not available")
             msg().exception()
-            raise
-        msg().error("Error - no final structure available")
+        msg().error("Force constants not available")
+        msg().exception()
+        return None
+
 
 class OldSystemPM(SystemPM):
     def __init__(self,url=None):
