@@ -123,7 +123,7 @@ class StructureApplet(Applet,p4vasp.Selection.SelectionListener):
         Applet.__init__(self)
         self.gladefile="structureapplet.glade"
         self.gladename="applet_frame"
-        self.required=["NAME","INITIAL_STRUCTURE","FINAL_STRUCTURE","STRUCTURE_SEQUENCE_L"]
+        self.required=["NAME","INITIAL_STRUCTURE","FINAL_STRUCTURE","PRIMITIVE_STRUCTURE","STRUCTURE_SEQUENCE_L"]
         self.swin=None
         self.measure=None
         self.radius_factor=1.0
@@ -204,6 +204,11 @@ class StructureApplet(Applet,p4vasp.Selection.SelectionListener):
                 item.connect("activate",self.on_structureitem_clicked_handler,-2)
                 menu.append(item)
                 item.show()
+            if self.system.current("PRIMITIVE_STRUCTURE") is not None:
+                item=gtk.MenuItem("Primitive cell")
+                item.connect("activate",self.on_structureitem_clicked_handler,-2)
+                menu.append(item)
+                item.show()
             seq=self.system.current("STRUCTURE_SEQUENCE_L")
             if seq is not None:
                 for i in range(len(seq)):
