@@ -109,6 +109,15 @@ class StructureWindowControlApplet(Applet,p4vasp.Selection.SelectionListener):
                 if swa.sequencetype==swa.FINAL_SEQUENCE:
                     omenu.set_history(I)
                 I+=1
+            if swsystem.PRIMITIVE_STRUCTURE is not None:
+                item=gtk.MenuItem("Primitive cell")
+                item.connect("activate",self.on_structureitem_clicked_handler,
+                swa.PRIMITIVE_SEQUENCE)
+                menu.append(item)
+                item.show()
+                if swa.sequencetype==swa.PRIMITIVE_SEQUENCE:
+                    omenu.set_history(I)
+                I+=1
             if swsystem.STRUCTURE_SEQUENCE_L is not None:
                 item=gtk.MenuItem("Arbitrary Sequence")
                 item.connect("activate",self.on_structureitem_clicked_handler,
