@@ -1558,10 +1558,12 @@ class YAxis(Axis):
 
 
 class Graph(UserList,Cloneable):
+    world_p          = re.compile("@\\s+world\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)")
     world_xmin_p     = re.compile("@\\s+world\\s+xmin\\s+([0-9eE.+-]+)")
     world_xmax_p     = re.compile("@\\s+world\\s+xmax\\s+([0-9eE.+-]+)")
     world_ymin_p     = re.compile("@\\s+world\\s+ymin\\s+([0-9eE.+-]+)")
     world_ymax_p     = re.compile("@\\s+world\\s+ymax\\s+([0-9eE.+-]+)")
+    view_p           = re.compile("@\\s+view\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)\\s+([0-9eE.+-]+)")
     view_xmin_p      = re.compile("@\\s+view\\s+xmin\\s+([0-9eE.+-]+)")
     view_xmax_p      = re.compile("@\\s+view\\s+xmax\\s+([0-9eE.+-]+)")
     view_ymin_p      = re.compile("@\\s+view\\s+ymin\\s+([0-9eE.+-]+)")
@@ -1812,6 +1814,13 @@ class Graph(UserList,Cloneable):
 
     def parseGraceStatement(self,s):
         #print "parseGraceStatement",s
+        m=self.world_p.match(s)
+        if m:
+            self.world_xmin=float(m.group(1))
+            self.world_ymin=float(m.group(2))
+            self.world_xmax=float(m.group(3))
+            self.world_ymax=float(m.group(4))
+            return 1
         m=self.world_xmin_p.match(s)
         if m:
             self.world_xmin=float(m.group(1))
@@ -1828,6 +1837,13 @@ class Graph(UserList,Cloneable):
         if m:
             self.world_ymax=float(m.group(1))
             return 1
+        m=self.view_p.match(s)
+        if m:
+            self.view_xmin=float(m.group(1))
+            self.view_xmax=float(m.group(2))
+            self.view_ymin=float(m.group(3))
+            self.view_ymax=float(m.group(4))
+            return 1
         m=self.view_xmin_p.match(s)
         if m:
             self.view_xmin=float(m.group(1))
