@@ -2,7 +2,7 @@
  *  p4vasp is a GUI-program and library for processing outputs of the
  *  Vienna Ab-inition Simulation Package (VASP)
  *  (see http://cms.mpi.univie.ac.at/vasp/Welcome.html)
- *  
+ *
  *  Copyright (C) 2003  Orest Dubay <odubay@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 #include <p4vasp/ChgcarSmear.h>
 #include <p4vasp/Exceptions.h>
 #include <p4vasp/vecutils3d.h>
+#include <locale.h>
 
 const char *Chgcar::getClassName(){
   return "Chgcar";
@@ -166,6 +167,7 @@ int Chgcar::read(char *path){
 
 int Chgcar::read(FILE *f){
   checklock("read(FILE)");
+  setlocale (LC_ALL,"C");
   is_statistics=false;
   char *line;
   char **words;
@@ -301,14 +303,14 @@ int Chgcar::write(char *path){
 int Chgcar::downSampleByFactors(int x,int y,int z){
 #if VERBOSE>1
   printf("Chgcar::downSampleByFactors(%d,%d,%d)\n",x,y,z);
-#endif  
+#endif
   checklock("downSampleByFactors()");
 #if CHECK>0
   if (data==NULL){
     THROW_NP_EXC("No data in Chgcar.downSampleByFactors().");
   }
   if ((x<=0)||(x>nx)||(y<=0)||(y>ny)||(z<=0)||(z>nz)){
-    char s[256];    
+    char s[256];
     snprintf(s,250,"Factors out of range in Chgcar.downSampleByFactors(%d, %d, %d); (nx=%ld,ny=%ld,nz=%ld)\n",
       x,y,z,nx,ny,nz);
     THROW_EXC(s);
@@ -337,7 +339,7 @@ int Chgcar::downSampleByFactors(int x,int y,int z){
               ch+=getRaw(i*x+ii,j*y+jj,k*z+kk);
             }
           }
-        }	
+        }
         ndata[i+(j+k*nny)*nnx]=ch;
       }
     }
@@ -349,7 +351,7 @@ int Chgcar::downSampleByFactors(int x,int y,int z){
   data=ndata;
 #if VERBOSE>1
   printf("Chgcar::downSampleByFactors(%d,%d,%d) -\n",x,y,z);
-#endif  
+#endif
   return 0;
 }
 
@@ -376,13 +378,13 @@ float Chgcar::getRaw(int i,int j,int k){
     THROW_NP_EXC("No data in Chgcar.getRaw().");
   }
   if ((i<0)||(i>=nx)){
-    THROW_R_EXC("getRaw() 1st index out of range.",0,nx,i);    
+    THROW_R_EXC("getRaw() 1st index out of range.",0,nx,i);
   }
   if ((j<0)||(j>=ny)){
-    THROW_R_EXC("getRaw() 2nd index out of range.",0,ny,j);    
+    THROW_R_EXC("getRaw() 2nd index out of range.",0,ny,j);
   }
   if ((k<0)||(k>=nz)){
-    THROW_R_EXC("getRaw() 3rd index out of range.",0,nz,k);    
+    THROW_R_EXC("getRaw() 3rd index out of range.",0,nz,k);
   }
 #endif
   return data[i+(j+k*ny)*nx];
@@ -409,13 +411,13 @@ void Chgcar::setRaw(int i,int j,int k,float val){
     THROW_NP_EXC("No data in Chgcar.setRaw().");
   }
   if ((i<0)||(i>=nx)){
-    THROW_R_EXC("setRaw() 1st index out of range.",0,nx,i);    
+    THROW_R_EXC("setRaw() 1st index out of range.",0,nx,i);
   }
   if ((j<0)||(j>=ny)){
-    THROW_R_EXC("setRaw() 2nd index out of range.",0,ny,j);    
+    THROW_R_EXC("setRaw() 2nd index out of range.",0,ny,j);
   }
   if ((k<0)||(k>=nz)){
-    THROW_R_EXC("setRaw() 3rd index out of range.",0,nz,k);    
+    THROW_R_EXC("setRaw() 3rd index out of range.",0,nz,k);
   }
 #endif
   data[i+(j+k*ny)*nx]=val;
@@ -566,7 +568,7 @@ void Chgcar::setChgcar(Chgcar *c){
     }
     unsigned long length=nx*ny*nz;
     data=new float[length];
-    memcpy(data,c->data,length*sizeof(float));    
+    memcpy(data,c->data,length*sizeof(float));
     is_statistics=c->is_statistics;
     minimum=c->minimum;
     maximum=c->maximum;
@@ -576,7 +578,7 @@ void Chgcar::setChgcar(Chgcar *c){
 }
 
 Chgcar *Chgcar::clone(){
-  checklock("clone()");  
+  checklock("clone()");
   Chgcar *c=new Chgcar();
   c->setChgcar(this);
   return c;
@@ -603,8 +605,9 @@ long ReadChgcarProcess::next(){
   char *line;
   char **words;
   int r;
-  is_status=true;  
-  is_error=false;  
+  is_status=true;
+  is_error=false;
+  setlocale (LC_ALL,"C");
   if (_step==0){
     sprintf(buff,"Reading Chgcar headder");
     chgcar->unlock();
@@ -699,8 +702,8 @@ long ReadChgcarProcess::next(){
     _total=chgcar->length;
     return 1;
   }
-  else{    
-    is_error=false;  
+  else{
+    is_error=false;
     for (long i=_step-1;i<chgcar->length; i++){
       line=getWord(file);
       if (line==NULL){
@@ -717,7 +720,7 @@ long ReadChgcarProcess::next(){
         _step=i+2;
 	return _step;
       }
-    }    
+    }
   }
   chgcar->unlock();
   sprintf(buff,"Chgcar read OK.");
@@ -746,7 +749,7 @@ void Chgcar::calculatePlaneStatisticsX(int n){
 	max=x;
       }
       avg+=x;
-      avg2+=x*x;      
+      avg2+=x*x;
     }
   }
   unsigned long N=ny*nz;
@@ -777,7 +780,7 @@ void Chgcar::calculatePlaneStatisticsY(int n){
 	max=x;
       }
       avg+=x;
-      avg2+=x*x;      
+      avg2+=x*x;
     }
   }
   unsigned long N=nx*nz;
@@ -809,7 +812,7 @@ void Chgcar::calculatePlaneStatisticsZ(int n){
 	max=x;
       }
       avg+=x;
-      avg2+=x*x;      
+      avg2+=x*x;
     }
   }
   unsigned long N=nx*ny;
@@ -826,7 +829,7 @@ FArray2D *Chgcar::getPlaneX(int n){
     THROW_NP_EXC("data is NULL in Chgcar.getPlaneX(n)");
   }
 #endif
-  FArray2D *a=new FArray2D(ny,nz);  
+  FArray2D *a=new FArray2D(ny,nz);
   for(int i=0; i<ny; i++){
     for (int j=0; j<nz; j++){
       a->set(i,j,getRaw(n,i,j));
@@ -841,7 +844,7 @@ FArray2D *Chgcar::getPlaneY(int n){
     THROW_NP_EXC("data is NULL in Chgcar.getPlaneX(n)");
   }
 #endif
-  FArray2D *a=new FArray2D(nx,nz);  
+  FArray2D *a=new FArray2D(nx,nz);
   for(int i=0; i<nx; i++){
     for (int j=0; j<nz; j++){
       a->set(i,j,getRaw(i,n,j));
@@ -874,7 +877,7 @@ int Chgcar::searchMinPlaneX(){
     if (plane_average<min){
       min=plane_average;
       index=i;
-    }    
+    }
   }
   return index;
 }
@@ -888,7 +891,7 @@ int Chgcar::searchMinPlaneY(){
     if (plane_average<min){
       min=plane_average;
       index=i;
-    }    
+    }
   }
   return index;
 }
@@ -902,7 +905,7 @@ int Chgcar::searchMinPlaneZ(){
      if (plane_average<min){
       min=plane_average;
       index=i;
-    }    
+    }
   }
   return index;
 }
@@ -952,7 +955,7 @@ sigmax, double sigmay,double sigmaz,double limit=0.01){
   sz=sigmaz;
   double fx=factor(0);
   double fy=factor(1);
-  double fz=factor(2);  
+  double fz=factor(2);
   dx=(sx<=0.0)?(0):int(sqrt(-log(limit*sx*sqrt(2*M_PI))/fx));
   dy=(sy<=0.0)?(0):int(sqrt(-log(limit*sy*sqrt(2*M_PI))/fy));
   dz=(sz<=0.0)?(0):int(sqrt(-log(limit*sz*sqrt(2*M_PI))/fz));
@@ -993,7 +996,7 @@ double *ChgcarPlaneProcess::createWeights(int d,double factor){
     w[0]=1.0;
     return w;
   }
-  double sum=0.0;  
+  double sum=0.0;
   w= new double[2*d+1];
   for (int i=-d;i<=d;i++){
     w[d+i]=exp(-i*i*factor);
@@ -1052,13 +1055,13 @@ FArray2D *ChgcarPlaneProcess::getPlane(){
 }
 
 long ChgcarPlaneProcess::next(){
-  is_status=true;  
-  is_error=false;  
+  is_status=true;
+  is_error=false;
   sprintf(buff,"Smoothing %ld %s plane.",n,planeName());
   if (_step<_total){
     for (long i=0; i<dim;i++){
       double sum=0.0;
-      switch(dir){    
+      switch(dir){
         case 0:
 	  for (int jx=-dx;jx<=dx;jx++){
 	    for (int jy=-dy;jy<=dy;jy++){
