@@ -407,11 +407,11 @@ void VisStructureDrawer::fillInfo(){
 
     if (structure->len()!=si->getNatoms()){
     /*
-      THROW_EXC("Inconsistant structure: "
+      THROW_EXC("Inconsistent structure: "
         	"len(structure) != structure.getNatoms()\n"
 		"found in VisStructureDrawer::fillInfo()");
 		*/
-      printf("Inconsistant (corrupted) structure: "
+      printf("Inconsistent (corrupted) structure: "
              "len(structure)=%d  differs from structure.getNatoms()=%d\n"
 	     "found in VisStructureDrawer::fillInfo()",structure->len(),si->getNatoms());
       
