@@ -2,7 +2,7 @@
  *  p4vasp is a GUI-program and library for processing outputs of the
  *  Vienna Ab-inition Simulation Package (VASP)
  *  (see http://cms.mpi.univie.ac.at/vasp/Welcome.html)
- *  
+ *
  *  Copyright (C) 2003  Orest Dubay <odubay@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,12 +28,14 @@
 #include <p4vasp/Exceptions.h>
 #include <p4vasp/utils.h>
 #include <p4vasp/vecutils3d.h>
+#include <locale.h>
 
 double *createvec3d(char *s){
   double *v= new double [3];
+  setlocale (LC_ALL,"C");
   s=strip(s);
   char **words=splitWords(s);
-  if (words[0]==NULL){    
+  if (words[0]==NULL){
     v[0]=0.0;
     v[1]=0.0;
     v[2]=0.0;
@@ -83,15 +85,15 @@ double *createmat3d(double a11,double a12,double a13,
 		    double a31,double a32,double a33){
 
   double *m = new double[9];
-  m[0]=a11;		    
-  m[1]=a12;		    
-  m[2]=a13;		    
-  m[3]=a21;		    
-  m[4]=a22;		    
-  m[5]=a23;		    
-  m[6]=a31;		    
-  m[7]=a32;		    
-  m[8]=a33;		    
+  m[0]=a11;
+  m[1]=a12;
+  m[2]=a13;
+  m[3]=a21;
+  m[4]=a22;
+  m[5]=a23;
+  m[6]=a31;
+  m[7]=a32;
+  m[8]=a33;
   return m;
 }
 
@@ -100,15 +102,15 @@ void setmat3d(double *dest,
               double a21,double a22,double a23,
 	      double a31,double a32,double a33){
 
-  dest[0]=a11;		    
-  dest[1]=a12;		    
-  dest[2]=a13;		    
-  dest[3]=a21;		    
-  dest[4]=a22;		    
-  dest[5]=a23;		    
-  dest[6]=a31;		    
-  dest[7]=a32;		    
-  dest[8]=a33;		    
+  dest[0]=a11;
+  dest[1]=a12;
+  dest[2]=a13;
+  dest[3]=a21;
+  dest[4]=a22;
+  dest[5]=a23;
+  dest[6]=a31;
+  dest[7]=a32;
+  dest[8]=a33;
 }
 
 void deletemat3d(double *dest){
@@ -119,7 +121,7 @@ void deletemat3d(double *dest){
 }
 
 
-double getVecElement3d(double *dest, int i){  
+double getVecElement3d(double *dest, int i){
 #if CHECK>0
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in getVecElement3d(dest,i)");
@@ -127,11 +129,11 @@ double getVecElement3d(double *dest, int i){
   if ((i<0) || (i>=3)){
     NTHROW_R_EXC("Index out of range in getVecElement3d(dest,i)",0,3,i);
   }
-#endif  
+#endif
   return dest[i];
 }
 
-void setVecElement3d(double *dest, int i,double value){  
+void setVecElement3d(double *dest, int i,double value){
 #if CHECK>0
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in setVecElement3d(dest,i,value)");
@@ -139,12 +141,12 @@ void setVecElement3d(double *dest, int i,double value){
   if ((i<0) || (i>=3)){
     NTHROW_R_EXC("Index out of range in setVecElement3d(dest,i,value)",0,3,i);
   }
-#endif  
+#endif
   dest[i]=value;
 }
 
 
-double *getMatVecElement3d(double *m, int i){  
+double *getMatVecElement3d(double *m, int i){
 #if CHECK>0
   if (m==NULL){
     NTHROW_NP_EXC("m=NULL in getMatVecElement3d(m,i)");
@@ -152,11 +154,11 @@ double *getMatVecElement3d(double *m, int i){
   if ((i<0) || (i>=3)){
     NTHROW_R_EXC("Index out of range in getMatVecElement3d(m,i)",0,3,i);
   }
-#endif  
+#endif
   return &m[3*i];
 }
 
-void setMatVecElement3d(double *m, int i,double *v){  
+void setMatVecElement3d(double *m, int i,double *v){
 #if CHECK>0
   if (m==NULL){
     NTHROW_NP_EXC("m=NULL in setMatVecElement3d(m,i,value)");
@@ -167,14 +169,14 @@ void setMatVecElement3d(double *m, int i,double *v){
   if ((i<0) || (i>=3)){
     NTHROW_R_EXC("Index out of range in setMatVecElement3d(m,i,value)",0,3,i);
   }
-#endif  
+#endif
 
   m[3*i]  =v[0];
   m[3*i+1]=v[1];
   m[3*i+2]=v[2];
 }
 
-double getMatElement3d(double *m, int i,int j){  
+double getMatElement3d(double *m, int i,int j){
 #if CHECK>0
   if (m==NULL){
     NTHROW_NP_EXC("m=NULL in getMatElement3d(m,i,j)");
@@ -185,11 +187,11 @@ double getMatElement3d(double *m, int i,int j){
   if ((j<0) || (j>=3)){
     NTHROW_R_EXC("Index j out of range in getMatElement3d(m,i,j)",0,3,j);
   }
-#endif  
+#endif
   return m[3*i+j];
 }
 
-void setMatElement3d(double *m, int i,int j,double value){  
+void setMatElement3d(double *m, int i,int j,double value){
 #if CHECK>0
   if (m==NULL){
     NTHROW_NP_EXC("m=NULL in setMatElement3d(m,i,j,value)");
@@ -200,7 +202,7 @@ void setMatElement3d(double *m, int i,int j,double value){
   if ((j<0) || (j>=3)){
     NTHROW_R_EXC("Index j out of range in setMatElement3d(m,i,j,value)",0,3,j);
   }
-#endif  
+#endif
   m[3*i+j]=value;
 }
 
@@ -221,7 +223,7 @@ double *add3d(double *dest,double *a){
   return dest;
 }
 
-double *plus3d(double *dest,double *a,double *b){  
+double *plus3d(double *dest,double *a,double *b){
 #if CHECK>0
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in plus3d(dest,a,b)");
@@ -232,16 +234,16 @@ double *plus3d(double *dest,double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in plus3d(dest,a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]+b[0];
   dest[1]=a[1]+b[1];
   dest[2]=a[2]+b[2];
   return dest;
 }
 
-double *createplus3d(double *a,double *b){  
+double *createplus3d(double *a,double *b){
   double *dest = new double[3];
-#if CHECK>0  
+#if CHECK>0
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createplus3d(a,b)");
   }
@@ -251,16 +253,16 @@ double *createplus3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createplus3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]+b[0];
   dest[1]=a[1]+b[1];
   dest[2]=a[2]+b[2];
   return dest;
 }
 
-double *createplusmat3d(double *a,double *b){  
+double *createplusmat3d(double *a,double *b){
   double *dest = new double[9];
-#if CHECK>0  
+#if CHECK>0
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createplusmat3d(a,b)");
   }
@@ -270,7 +272,7 @@ double *createplusmat3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createplusmat3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]+b[0];
   dest[1]=a[1]+b[1];
   dest[2]=a[2]+b[2];
@@ -292,7 +294,7 @@ double *sub3d(double *dest,double *a){
   if (a==NULL){
     NTHROW_NP_EXC("a=NULL in sub3d(dest,a)");
   }
-#endif  
+#endif
   dest[0]-=a[0];
   dest[1]-=a[1];
   dest[2]-=a[2];
@@ -310,7 +312,7 @@ double *minus3d(double *dest,double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in minus3d(dest,a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]-b[0];
   dest[1]=a[1]-b[1];
   dest[2]=a[2]-b[2];
@@ -329,7 +331,7 @@ double *createminus3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createminus3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]-b[0];
   dest[1]=a[1]-b[1];
   dest[2]=a[2]-b[2];
@@ -348,7 +350,7 @@ double *createminusmat3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createminusmat3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]-b[0];
   dest[1]=a[1]-b[1];
   dest[2]=a[2]-b[2];
@@ -370,7 +372,7 @@ double *createneg3d(double *v){
   if (v==NULL){
     NTHROW_NP_EXC("createneg3d(NULL)");
   }
-#endif  
+#endif
   dest[0]=-v[0];
   dest[1]=-v[1];
   dest[2]=-v[2];
@@ -386,7 +388,7 @@ double *createnegmat3d(double *m){
   if (m==NULL){
     NTHROW_NP_EXC("createnegmat3d(NULL)");
   }
-#endif  
+#endif
   dest[0]=-m[0];
   dest[1]=-m[1];
   dest[2]=-m[2];
@@ -404,7 +406,7 @@ double *neg3d(double *v){
   if (v==NULL){
     NTHROW_NP_EXC("neg3d(NULL)");
   }
-#endif  
+#endif
   v[0]=-v[0];
   v[1]=-v[1];
   v[2]=-v[2];
@@ -416,7 +418,7 @@ double *scalmul3d(double *dest,double a){
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in scalmul3d(dest,a)");
   }
-#endif  
+#endif
   dest[0]*=a;
   dest[1]*=a;
   dest[2]*=a;
@@ -432,7 +434,7 @@ double *createscalmultiply3d(double *v,double a){
   if (v==NULL){
     NTHROW_NP_EXC("v=NULL in createscalmultiply3d(v,a)");
   }
-#endif  
+#endif
   dest[0]=v[0]*a;
   dest[1]=v[1]*a;
   dest[2]=v[2]*a;
@@ -448,8 +450,8 @@ double *scaldiv3d(double *dest,double a){
   if (a==0.0){
     NTHROW_NP_EXC("a=0.0 in scaldiv3d(dest,a)");
   }
-#endif  
-  
+#endif
+
   dest[0]/=a;
   dest[1]/=a;
   dest[2]/=a;
@@ -468,7 +470,7 @@ double *createscaldivide3d(double *v,double a){
   if (a==0.0){
     NTHROW_NP_EXC("a=0.0 in createscaldivide3d(v,a)");
   }
-#endif  
+#endif
   dest[0]=v[0]/a;
   dest[1]=v[1]/a;
   dest[2]=v[2]/a;
@@ -484,7 +486,7 @@ double *copy3d(double *dest,double *a){
   if (a==NULL){
     NTHROW_NP_EXC("a=NULL in copy3d(dest,a)");
   }
-#endif  
+#endif
   dest[0]=a[0];
   dest[1]=a[1];
   dest[2]=a[2];
@@ -499,7 +501,7 @@ double *copymat3d(double *dest,double *a){
   if (a==NULL){
     NTHROW_NP_EXC("a=NULL in copymat3d(dest,a)");
   }
-#endif  
+#endif
   memcpy(dest,a,9*sizeof(double));
   return dest;
 }
@@ -513,7 +515,7 @@ double *clone3d(double *a){
   if (a==NULL){
     NTHROW_NP_EXC("v=NULL in clone3d(v)");
   }
-#endif  
+#endif
   dest[0]=a[0];
   dest[1]=a[1];
   dest[2]=a[2];
@@ -529,7 +531,7 @@ double *clonemat3d(double *m){
   if (m==NULL){
     NTHROW_NP_EXC("m=NULL in clonemat3d(m)");
   }
-#endif  
+#endif
   memcpy(dest,m,9*sizeof(double));
   return dest;
 }
@@ -539,7 +541,7 @@ double veclength3d(double *dest){
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in veclength3d(dest)");
   }
-#endif  
+#endif
   return sqrt(dest[0]*dest[0]+dest[1]*dest[1]+dest[2]*dest[2]);
 }
 
@@ -566,7 +568,7 @@ double scalprod3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in scalprod3d(a,b)");
   }
-#endif  
+#endif
   return a[0]*b[0]+a[1]*b[1]+a[2]*b[2];
 }
 
@@ -581,7 +583,7 @@ double *crossprod3d(double *dest,double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in crossprod3d(dest,a,b)");
   }
-#endif  
+#endif
   dest[0]=a[1]*b[2]-a[2]*b[1];
   dest[1]=a[2]*b[0]-a[0]*b[2];
   dest[2]=a[0]*b[1]-a[1]*b[0];
@@ -600,7 +602,7 @@ double *createcrossprod3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createcrossprod3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[1]*b[2]-a[2]*b[1];
   dest[1]=a[2]*b[0]-a[0]*b[2];
   dest[2]=a[0]*b[1]-a[1]*b[0];
@@ -618,7 +620,7 @@ double *multiplymatvec3d(double *dest,double *a,double *v){
   if (v==NULL){
     NTHROW_NP_EXC("v=NULL in multiplymatvec3d(dest,a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]*v[0]+a[1]*v[1]+a[2]*v[2];
   dest[1]=a[3]*v[0]+a[4]*v[1]+a[5]*v[2];
   dest[2]=a[6]*v[0]+a[7]*v[1]+a[8]*v[2];
@@ -634,7 +636,7 @@ double *createmultiplymatscal3d(double *a,double v){
   if (a==NULL){
     NTHROW_NP_EXC("a=NULL in createmultiplymatvec3d(NULL,?)");
   }
-#endif  
+#endif
   dest[0]=a[0]*v;
   dest[1]=a[1]*v;
   dest[2]=a[2]*v;
@@ -659,7 +661,7 @@ double *createmultiplymatvec3d(double *a,double *v){
   if (v==NULL){
     NTHROW_NP_EXC("v=NULL in createmultiplymatvec3d(a,v)");
   }
-#endif  
+#endif
   dest[0]=a[0]*v[0]+a[1]*v[1]+a[2]*v[2];
   dest[1]=a[3]*v[0]+a[4]*v[1]+a[5]*v[2];
   dest[2]=a[6]*v[0]+a[7]*v[1]+a[8]*v[2];
@@ -675,7 +677,7 @@ double *mulmatvec3d(double *a,double *v){
   if (v==NULL){
     NTHROW_NP_EXC("v=NULL in mulmatvec3d(a,v)");
   }
-#endif  
+#endif
   double dest[3];
   dest[0]=a[0]*v[0]+a[1]*v[1]+a[2]*v[2];
   dest[1]=a[3]*v[0]+a[4]*v[1]+a[5]*v[2];
@@ -698,7 +700,7 @@ double *multiplymatmat3d(double *dest,double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in multiplymatmat3d(?,?,NULL)");
   }
-#endif  
+#endif
   dest[0]=a[0]*b[0]+a[1]*b[3]+a[2]*b[6];
   dest[1]=a[0]*b[1]+a[1]*b[4]+a[2]*b[7];
   dest[2]=a[0]*b[2]+a[1]*b[5]+a[2]*b[8];
@@ -723,7 +725,7 @@ double *createmultiplymatmat3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in createmultiplymatmat3d(a,b)");
   }
-#endif  
+#endif
   dest[0]=a[0]*b[0]+a[1]*b[3]+a[2]*b[6];
   dest[1]=a[0]*b[1]+a[1]*b[4]+a[2]*b[7];
   dest[2]=a[0]*b[2]+a[1]*b[5]+a[2]*b[8];
@@ -745,7 +747,7 @@ double *mulmatmat3d(double *a,double *b){
   if (b==NULL){
     NTHROW_NP_EXC("b=NULL in mulmatmat3d(?,NULL)");
   }
-#endif  
+#endif
   double dest[9];
   dest[0]=a[0]*b[0]+a[1]*b[3]+a[2]*b[6];
   dest[1]=a[0]*b[1]+a[1]*b[4]+a[2]*b[7];
@@ -767,7 +769,7 @@ double *createrotmat3d(double x,double y,double z){
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createrotmat3d(x,y,z)");
   }
-#endif  
+#endif
   double cx=cos(x);
   double cy=cos(y);
   double cz=cos(z);
@@ -794,7 +796,7 @@ double *createrotmat3da(double x,double y,double z,double a){
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createrotmat3da(x,y,z,a)");
   }
-#endif  
+#endif
   double S=a/sqrt(x*x+y*y+z*z);
   x*=S;
   y*=S;
@@ -825,7 +827,7 @@ double *identitymat3d(double *dest){
   if (dest==NULL){
     NTHROW_NP_EXC("dest=NULL in identitymat3d(NULL)");
   }
-#endif  
+#endif
   dest[0]=1.0;
   dest[1]=0.0;
   dest[2]=0.0;
@@ -844,7 +846,7 @@ double *createidentitymat3d(){
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createidentitymat3d()");
   }
-#endif  
+#endif
   dest[0]=1.0;
   dest[1]=0.0;
   dest[2]=0.0;
@@ -863,7 +865,7 @@ double *zeromat3d(double *dest){
   if (dest==NULL){
     NTHROW_NP_EXC("zeromat3d(NULL)");
   }
-#endif  
+#endif
   dest[0]=0.0;
   dest[1]=0.0;
   dest[2]=0.0;
@@ -882,7 +884,7 @@ double *createzeromat3d(){
   if (dest==NULL){
     NTHROW_MA_EXC("dest allocation failed in createzeromat3d()");
   }
-#endif  
+#endif
   dest[0]=0.0;
   dest[1]=0.0;
   dest[2]=0.0;
@@ -900,7 +902,7 @@ double *transmat3d(double *dest){
   if (dest==NULL){
     NTHROW_NP_EXC("transmat3d(NULL)");
   }
-#endif  
+#endif
   double c;
 
   c=dest[1];
@@ -914,7 +916,7 @@ double *transmat3d(double *dest){
   c=dest[7];
   dest[7]=dest[5];
   dest[5]=c;
-  
+
   return dest;
 }
 
@@ -923,10 +925,8 @@ double detmat3d(double *dest){
   if (dest==NULL){
     NTHROW_NP_EXC("detmat3d(NULL)");
   }
-#endif  
+#endif
   return dest[0]*dest[4]*dest[8]+dest[1]*dest[5]*dest[6]+dest[3]*dest[7]*dest[2]
         -dest[2]*dest[4]*dest[6]-dest[1]*dest[3]*dest[8]-dest[5]*dest[7]*dest[0];
 
 }
-
-
